@@ -2,8 +2,10 @@ import logging
 from os import getcwd
 from os.path import dirname
 
-__version__ = '0.3.25'
-basedir = dirname(__file__)
+import pkg_resources
+
+__version__ = pkg_resources.get_distribution('sonusai').version
+BASEDIR = dirname(__file__)
 
 # create logger
 logger = logging.getLogger('sonusai')
@@ -16,7 +18,8 @@ logger.addHandler(console_handler)
 
 
 class SonusAIError(Exception):
-    pass
+    def __init__(self, value):
+        logger.error(value)
 
 
 # create file handler
