@@ -82,7 +82,10 @@ def genft(mixdb: MixtureDatabase,
           progress: tqdm = None,
           initial_i_sample_offset: int = 0,
           initial_i_frame_offset: int = 0,
-          initial_o_frame_offset: int = 0) -> (np.ndarray, np.ndarray, MixtureDatabase):
+          initial_o_frame_offset: int = 0) -> (np.ndarray,
+                                               np.ndarray,
+                                               np.ndarray,
+                                               MixtureDatabase):
     import ctypes
 
     from pyaaware import FeatureGenerator
@@ -202,8 +205,8 @@ def _process_mixture(mixid: int) -> None:
      _,
      segsnr[frame_indices]) = get_audio_and_truth_t(mixdb=mixdb,
                                                     mixture=record,
-                                                    target_audios=target_audios,
-                                                    noise_audios=noise_audios,
+                                                    raw_target_audios=target_audios,
+                                                    raw_noise_audios=noise_audios,
                                                     compute_truth=True,
                                                     compute_segsnr=compute_segsnr,
                                                     frame_based_segsnr=True)
