@@ -87,7 +87,12 @@ def genmix(mixdb: MixtureDatabase,
            progress: tqdm = None,
            initial_i_sample_offset: int = 0,
            initial_i_frame_offset: int = 0,
-           initial_o_frame_offset: int = 0) -> (np.ndarray, np.ndarray, np.ndarray, np.ndarray, MixtureDatabase):
+           initial_o_frame_offset: int = 0) -> (np.ndarray,
+                                                np.ndarray,
+                                                np.ndarray,
+                                                np.ndarray,
+                                                np.ndarray,
+                                                MixtureDatabase):
     import ctypes
 
     from tqdm import tqdm
@@ -211,8 +216,8 @@ def _process_mixture(mixid: int) -> None:
      noise[indices],
      segsnr[indices]) = get_audio_and_truth_t(mixdb=mixdb,
                                               mixture=record,
-                                              target_audios=target_audios,
-                                              noise_audios=noise_audios,
+                                              raw_target_audios=target_audios,
+                                              raw_noise_audios=noise_audios,
                                               compute_truth=compute_truth,
                                               compute_segsnr=compute_segsnr)
 
