@@ -143,6 +143,7 @@ def genmixdb(file: str = None,
     from sonusai.mixture import TruthSettings
     from sonusai.mixture import balance_targets
     from sonusai.mixture import build_noise_audios
+    from sonusai.mixture import evaluate_random_rule
     from sonusai.mixture import get_augmentation_indices_for_mixup
     from sonusai.mixture import get_augmentations
     from sonusai.mixture import get_augmented_target_indices_for_mixup
@@ -156,9 +157,14 @@ def genmixdb(file: str = None,
     from sonusai.mixture import load_config
     from sonusai.mixture import log_duration_and_sizes
     from sonusai.mixture import read_raw_target_audio
+    from sonusai.mixture import SAMPLE_RATE
     from sonusai.mixture import update_truth_settings
     from sonusai.utils import dataclass_from_dict
     from sonusai.utils import p_tqdm_map
+    from sonusai.utils import seconds_to_hms
+
+    if logging:
+        logger.info('')
 
     if (file is None and config is None) or (file is not None and config is not None):
         raise SonusAIError(f'Must specify either file name or config')
@@ -182,6 +188,7 @@ def genmixdb(file: str = None,
     if logging:
         logger.debug('List of targets:')
         logger.debug(yaml.dump([sub.name for sub in target_files], default_flow_style=False))
+        logger.debug('')
 
     if logging:
         logger.info('Collecting noises')
@@ -189,6 +196,7 @@ def genmixdb(file: str = None,
     if logging:
         logger.debug('List of noises:')
         logger.debug(yaml.dump([sub.name for sub in noise_files], default_flow_style=False))
+        logger.debug('')
 
     if logging:
         logger.info('Collecting target augmentations')
@@ -213,6 +221,7 @@ def genmixdb(file: str = None,
 
     if logging:
         logger.debug(f'SNRs: {config["snrs"]}\n')
+        logger.debug(f'Random SNRs: {config["random_snrs"]}\n')
         logger.debug(f'Exhaustive noise: {config["exhaustive_noise"]}\n')
 
     if config['truth_mode'] not in ['normal', 'mutex']:
@@ -243,6 +252,7 @@ def genmixdb(file: str = None,
         noise_augmentations=noise_augmentations,
         noises=noise_files,
         num_classes=config['num_classes'],
+        random_snrs=config['random_snrs'],
         seed=config['seed'],
         snrs=config['snrs'],
         target_augmentations=target_augmentations,
@@ -254,8 +264,22 @@ def genmixdb(file: str = None,
 
     MP_DICT['mixdb'] = mixdb
 
+    if logging:
+        logger.info('')
+
     raw_target_audio = read_raw_target_audio(mixdb=mixdb, show_progress=show_progress)
+    raw_target_audio_samples = sum([len(x) for x in raw_target_audio])
+    if logging:
+        logger.info('')
+        logger.info(f'Raw target audio: {seconds_to_hms(seconds=raw_target_audio_samples / SAMPLE_RATE)}')
+        logger.info('')
+
     noise_audios = build_noise_audios(mixdb=mixdb, show_progress=show_progress)
+    noise_audio_samples = sum([len(xa) for x in noise_audios for xa in x])
+    if logging:
+        logger.info('')
+        logger.info(f'Augmented noise audio: {seconds_to_hms(seconds=noise_audio_samples / SAMPLE_RATE)}')
+        logger.info('')
 
     MP_DICT['raw_target_audio'] = raw_target_audio
     MP_DICT['noise_audios'] = noise_audios
@@ -280,8 +304,8 @@ def genmixdb(file: str = None,
                     length += fs.feature_step_samples - int(length % fs.feature_step_samples)
                 total_duration += float(length) / sonusai.mixture.SAMPLE_RATE
 
-    target_sets *= len(mixdb.snrs)
-    total_duration *= len(mixdb.snrs)
+    target_sets *= len(mixdb.snrs) + len(mixdb.random_snrs)
+    total_duration *= len(mixdb.snrs) + len(mixdb.random_snrs)
     noise_sets = len(noise_files) * len(noise_augmentations) if mixdb.exhaustive_noise else 1
     total_mixtures = noise_sets * target_sets
     if logging:
@@ -298,7 +322,9 @@ def genmixdb(file: str = None,
         logger.info(f'Feature shape:        {fs.stride} x {fs.num_bands} ({fs.stride * fs.num_bands} total params)')
         logger.info(f'Feature samples:      {fs.feature_samples} samples ({fs.feature_ms} ms)')
         logger.info(f'Feature step samples: {fs.feature_step_samples} samples ({fs.feature_step_ms} ms)')
+        logger.info('')
 
+    used_noise_samples = 0
     if mixdb.exhaustive_noise:
         # Get indices and offsets
         # mixtures is a nested list: noise, target
@@ -309,11 +335,13 @@ def genmixdb(file: str = None,
                 mixtures.append(list())
                 noise_offset = 0
                 noise_length = len(noise_audios[noise_file_index][noise_augmentation_index])
+
                 for mixup in mixups:
                     augmented_target_indices_for_mixup = get_augmented_target_indices_for_mixup(
                         mixdb=mixdb,
                         augmented_targets=augmented_targets,
                         mixup=mixup)
+
                     for augmented_target_indices_for_mixup in augmented_target_indices_for_mixup:
                         (target_file_index,
                          target_augmentation_index,
@@ -331,9 +359,25 @@ def genmixdb(file: str = None,
                                 noise_offset=noise_offset,
                                 noise_augmentation_index=noise_augmentation_index,
                                 snr=snr,
+                                random_snr=False,
                             ))
 
                             noise_offset = int((noise_offset + target_length) % noise_length)
+                            used_noise_samples += target_length
+
+                        for random_snr in mixdb.random_snrs:
+                            mixtures[-1].append(Mixture(
+                                target_file_index=target_file_index,
+                                target_augmentation_index=target_augmentation_index,
+                                noise_file_index=noise_file_index,
+                                noise_offset=noise_offset,
+                                noise_augmentation_index=noise_augmentation_index,
+                                snr=evaluate_random_rule(random_snr),
+                                random_snr=True,
+                            ))
+
+                            noise_offset = int((noise_offset + target_length) % noise_length)
+                            used_noise_samples += target_length
 
         # Fill in the details
         progress = tqdm(total=total_mixtures, desc='genmixdb', disable=not show_progress)
@@ -367,27 +411,47 @@ def genmixdb(file: str = None,
                     augmented_targets=augmented_targets,
                     raw_target_audio=raw_target_audio)
 
-                if noise_offset + target_length >= len(noise_audios[noise_file_index][noise_augmentation_index]):
-                    if noise_offset == 0:
-                        raise SonusAIError('Length of target audio exceeds length of noise audio')
-
-                    noise_offset = 0
-                    noise_augmentation_index += 1
-                    if noise_augmentation_index == len(noise_audios[noise_file_index]):
-                        noise_augmentation_index = 0
-                        noise_file_index += 1
-                        if noise_file_index == len(noise_audios):
-                            noise_file_index = 0
-
                 for snr in mixdb.snrs:
+                    (noise_file_index,
+                     noise_augmentation_index,
+                     noise_offset) = _get_next_noise_offset(target_length=target_length,
+                                                            noise_audios=noise_audios,
+                                                            noise_file_index=noise_file_index,
+                                                            noise_augmentation_index=noise_augmentation_index,
+                                                            noise_offset=noise_offset)
+
                     mixtures.append(Mixture(target_file_index=target_file_index,
                                             target_augmentation_index=target_augmentation_index,
                                             noise_file_index=noise_file_index,
                                             noise_augmentation_index=noise_augmentation_index,
                                             noise_offset=noise_offset,
-                                            snr=snr))
+                                            snr=snr,
+                                            random_snr=False,
+                                            ))
 
-                noise_offset += target_length
+                    noise_offset += target_length
+                    used_noise_samples += target_length
+
+                for random_snr in mixdb.random_snrs:
+                    (noise_file_index,
+                     noise_augmentation_index,
+                     noise_offset) = _get_next_noise_offset(target_length=target_length,
+                                                            noise_audios=noise_audios,
+                                                            noise_file_index=noise_file_index,
+                                                            noise_augmentation_index=noise_augmentation_index,
+                                                            noise_offset=noise_offset)
+
+                    mixtures.append(Mixture(target_file_index=target_file_index,
+                                            target_augmentation_index=target_augmentation_index,
+                                            noise_file_index=noise_file_index,
+                                            noise_augmentation_index=noise_augmentation_index,
+                                            noise_offset=noise_offset,
+                                            snr=evaluate_random_rule(random_snr),
+                                            random_snr=True,
+                                            ))
+
+                    noise_offset += target_length
+                    used_noise_samples += target_length
 
         # Fill in the details
         progress = tqdm(total=total_mixtures, desc='genmixdb', disable=not show_progress)
@@ -407,10 +471,36 @@ def genmixdb(file: str = None,
                                num_bands=fs.num_bands,
                                stride=fs.stride,
                                desc='Actual')
+        noise_samples_percent = (float(used_noise_samples) / float(noise_audio_samples)) * 100
+        logger.info('')
+        logger.info(f'Used {noise_samples_percent:,.0f}% of noise audio')
+        logger.info('')
 
     return mixdb
 
 
+def _get_next_noise_offset(target_length: int,
+                           noise_audios: List[List[np.ndarray]],
+                           noise_file_index: int,
+                           noise_augmentation_index: int,
+                           noise_offset: int) -> (int, int, int):
+    from sonusai import SonusAIError
+
+    if noise_offset + target_length >= len(noise_audios[noise_file_index][noise_augmentation_index]):
+        if noise_offset == 0:
+            raise SonusAIError('Length of target audio exceeds length of noise audio')
+
+        noise_offset = 0
+        noise_augmentation_index += 1
+        if noise_augmentation_index == len(noise_audios[noise_file_index]):
+            noise_augmentation_index = 0
+            noise_file_index += 1
+            if noise_file_index == len(noise_audios):
+                noise_file_index = 0
+
+    return noise_file_index, noise_augmentation_index, noise_offset
+
+
 def _get_target_info(mixdb: MixtureDatabase,
                      augmented_target_indices_for_mixup: List[int],
                      augmented_targets: AugmentedTargets,
@@ -455,7 +545,7 @@ def _process_mixture(mixture: Mixture) -> Mixture:
 
     return process_mixture(mixture=mixture,
                            mixdb=MP_DICT['mixdb'],
-                           raw_target_audio=MP_DICT['raw_target_audio'],
+                           raw_target_audios=MP_DICT['raw_target_audio'],
                            augmented_noise_audio=MP_DICT['augmented_noise_audio'])
 
 
@@ -464,8 +554,8 @@ def _process_mixture_nen(mixture: Mixture) -> Mixture:
 
     return process_mixture_nen(mixture=mixture,
                                mixdb=MP_DICT['mixdb'],
-                               raw_target_audio=MP_DICT['raw_target_audio'],
-                               noise_audios=MP_DICT['noise_audios'])
+                               raw_target_audios=MP_DICT['raw_target_audio'],
+                               augmented_noise_audios=MP_DICT['noise_audios'])
 
 
 def main():
