@@ -30,13 +30,11 @@ def config_variable_substitution(config: dict) -> dict:
 
 def get_default_config() -> dict:
     """Load default SonusAI config."""
-    import json
-
-    import sonusai
     from sonusai import SonusAIError
+    from sonusai.mixture import DEFAULT_CONFIG
 
     try:
-        return raw_load_config(sonusai.mixture.DEFAULT_CONFIG)
+        return raw_load_config(DEFAULT_CONFIG)
     except Exception as e:
         raise SonusAIError(f'Error loading default config: {e}')
 
@@ -51,6 +49,8 @@ def update_config_from_file(name: str, config: dict) -> dict:
     from copy import deepcopy
 
     from sonusai import SonusAIError
+    from sonusai.mixture import REQUIRED_CONFIGS
+    from sonusai.mixture import VALID_CONFIGS
 
     new_config = deepcopy(config)
 
@@ -59,6 +59,12 @@ def update_config_from_file(name: str, config: dict) -> dict:
     except Exception as e:
         raise SonusAIError(f'Error loading config from {name}: {e}')
 
+    # Check for unrecognized keys
+    for key in given_config:
+        if key not in VALID_CONFIGS:
+            nice_list = '\n'.join([f'  {item}' for item in VALID_CONFIGS])
+            raise SonusAIError(f'Invalid config parameter in {name}: {key}.\nValid config parameters are:\n{nice_list}')
+
     # Use default config as base and overwrite with given config keys as found
     for key in new_config:
         if key in given_config:
@@ -79,28 +85,9 @@ def update_config_from_file(name: str, config: dict) -> dict:
     new_config['truth_settings'] = update_truth_settings(new_config['truth_settings'], default)
 
     # Check for required keys
-    required_keys = [
-        'class_balancing',
-        'class_balancing_augmentation',
-        'class_labels',
-        'class_weights_threshold',
-        'exhaustive_noise',
-        'feature',
-        'frame_size',
-        'noise_augmentations',
-        'noises',
-        'num_classes',
-        'seed',
-        'snrs',
-        'target_augmentations',
-        'targets',
-        'truth_mode',
-        'truth_reduction_function',
-        'truth_settings',
-    ]
-    for key in required_keys:
+    for key in REQUIRED_CONFIGS:
         if key not in new_config:
-            raise SonusAIError(f"Missing required '{key}' in {name}")
+            raise SonusAIError(f'Missing required config in {name}: {key}')
 
     return new_config
 
@@ -110,6 +97,7 @@ def update_truth_settings(given: Union[List[Dict], Dict], default: List[Dict] =
     from copy import deepcopy
 
     from sonusai import SonusAIError
+    from sonusai.mixture import VALID_TRUTH_SETTINGS
 
     truth_settings = deepcopy(given)
     if not isinstance(truth_settings, list):
@@ -118,18 +106,18 @@ def update_truth_settings(given: Union[List[Dict], Dict], default: List[Dict] =
     if default is not None and len(truth_settings) != len(default):
         raise SonusAIError(f'Length of given does not match default')
 
-    required_keys = [
-        'function',
-        'config',
-        'index',
-    ]
     for n in range(len(truth_settings)):
-        for key in required_keys:
+        for key in truth_settings[n]:
+            if key not in VALID_TRUTH_SETTINGS:
+                nice_list = '\n'.join([f'  {item}' for item in VALID_TRUTH_SETTINGS])
+                raise SonusAIError(f'Invalid truth_settings: {key}.\nValid truth_settings are:\n{nice_list}')
+
+        for key in VALID_TRUTH_SETTINGS:
             if key not in truth_settings[n]:
                 if default is not None and key in default[n]:
                     truth_settings[n][key] = default[n][key]
                 else:
-                    raise SonusAIError(f"Missing required '{key}' in truth_settings")
+                    raise SonusAIError(f'Missing required truth_settings: {key}')
 
     for truth_setting in truth_settings:
         if not isinstance(truth_setting['index'], list):
