@@ -8,11 +8,11 @@ from sonusai.mixture.mixdb import MixtureDatabase
 
 def _process_target_audio(mixdb: MixtureDatabase,
                           mixture: Mixture,
-                          raw_target_audio: List[np.ndarray]) -> np.ndarray:
+                          raw_target_audios: List[np.ndarray]) -> List[np.ndarray]:
     """Apply augmentation and update target metadata."""
     from sonusai import SonusAIError
     from sonusai.mixture import apply_augmentation
-    from sonusai.mixture import get_class_count
+    from sonusai.mixture import pad_to_samples
 
     target_file_index = mixture.target_file_index
     target_augmentation_index = mixture.target_augmentation_index
@@ -20,14 +20,14 @@ def _process_target_audio(mixdb: MixtureDatabase,
         raise SonusAIError('target_file_index and target_augmentation_index are not the same length')
 
     mixture.samples = 0
-    target_audio = list()
+    target_audios = list()
     mixture.target_gain = list()
     for idx in range(len(target_file_index)):
         target_augmentation = mixdb.target_augmentations[target_augmentation_index[idx]]
 
-        target_audio.append(apply_augmentation(audio_in=raw_target_audio[target_file_index[idx]],
-                                               augmentation=target_augmentation,
-                                               length_common_denominator=mixdb.feature_step_samples))
+        target_audios.append(apply_augmentation(audio_in=raw_target_audios[target_file_index[idx]],
+                                                augmentation=target_augmentation,
+                                                length_common_denominator=mixdb.feature_step_samples))
 
         # target_gain is used to back out the gain augmentation in order to return the target audio
         # to its normalized level when calculating truth.
@@ -37,73 +37,73 @@ def _process_target_audio(mixdb: MixtureDatabase,
             target_gain = 1
         mixture.target_gain.append(target_gain)
 
-    mixture.samples = max([len(item) for item in target_audio])
+    mixture.samples = max([len(item) for item in target_audios])
 
-    for idx in range(len(target_audio)):
-        pad = mixture.samples - len(target_audio[idx])
-        target_audio[idx] = np.pad(target_audio[idx], (0, pad), mode='constant', constant_values=0)
+    for idx in range(len(target_audios)):
+        target_audios[idx] = pad_to_samples(audio_in=target_audios[idx], samples=mixture.samples)
 
-    mixture.class_count = get_class_count(mixdb=mixdb,
-                                          mixture=mixture,
-                                          target_audio=target_audio)
-
-    return sum(target_audio)
+    return target_audios
 
 
 def process_target(mixture: Mixture,
                    mixdb: MixtureDatabase,
-                   raw_target_audio: List[np.ndarray]) -> Mixture:
+                   raw_target_audios: List[np.ndarray]) -> Mixture:
     """Apply augmentation and update target metadata."""
-    _process_target_audio(mixdb, mixture, raw_target_audio)
+    _process_target_audio(mixdb, mixture, raw_target_audios)
     return mixture
 
 
 def process_mixture(mixture: Mixture,
                     mixdb: MixtureDatabase,
-                    raw_target_audio: List[np.ndarray],
+                    raw_target_audios: List[np.ndarray],
                     augmented_noise_audio: np.ndarray) -> Mixture:
+    from sonusai.mixture import get_class_count
     from sonusai.mixture import get_next_noise
 
-    augmented_target_audio = _process_target_audio(mixdb=mixdb,
-                                                   mixture=mixture,
-                                                   raw_target_audio=raw_target_audio)
+    augmented_target_audios = _process_target_audio(mixdb=mixdb,
+                                                    mixture=mixture,
+                                                    raw_target_audios=raw_target_audios)
 
     noise_segment, _ = get_next_noise(offset_in=mixture.noise_offset,
                                       length=mixture.samples,
                                       audio_in=augmented_noise_audio)
 
-    return _update_mixture_gains(mixdb=mixdb,
-                                 mixture=mixture,
-                                 augmented_target_audio=augmented_target_audio,
-                                 noise_segment=noise_segment)
+    mixture = _update_mixture_gains(mixdb=mixdb,
+                                    mixture=mixture,
+                                    target_audios=augmented_target_audios,
+                                    noise_audio=noise_segment)
+
+    for idx in range(len(augmented_target_audios)):
+        augmented_target_audios[idx] = np.int16(
+            np.round(np.single(augmented_target_audios[idx]) * mixture.target_snr_gain))
+
+    mixture.class_count = get_class_count(mixdb=mixdb,
+                                          mixture=mixture,
+                                          target_audios=augmented_target_audios,
+                                          noise_audio=noise_segment)
+
+    return mixture
 
 
 def process_mixture_nen(mixture: Mixture,
                         mixdb: MixtureDatabase,
-                        raw_target_audio: List[np.ndarray],
-                        noise_audios: List[List[np.ndarray]]) -> Mixture:
-    from sonusai.mixture import get_next_noise
-
-    augmented_target_audio = _process_target_audio(mixdb=mixdb,
-                                                   mixture=mixture,
-                                                   raw_target_audio=raw_target_audio)
-
-    noise_segment, _ = get_next_noise(offset_in=mixture.noise_offset,
-                                      length=mixture.samples,
-                                      audio_in=noise_audios[mixture.noise_file_index][mixture.noise_augmentation_index])
-
-    return _update_mixture_gains(mixdb=mixdb,
-                                 mixture=mixture,
-                                 augmented_target_audio=augmented_target_audio,
-                                 noise_segment=noise_segment)
+                        raw_target_audios: List[np.ndarray],
+                        augmented_noise_audios: List[List[np.ndarray]]) -> Mixture:
+    augmented_noise_audio = augmented_noise_audios[mixture.noise_file_index][mixture.noise_augmentation_index]
+    return process_mixture(mixture=mixture,
+                           mixdb=mixdb,
+                           raw_target_audios=raw_target_audios,
+                           augmented_noise_audio=augmented_noise_audio)
 
 
 def _update_mixture_gains(mixdb: MixtureDatabase,
                           mixture: Mixture,
-                          augmented_target_audio: np.ndarray,
-                          noise_segment: np.ndarray) -> Mixture:
+                          target_audios: List[np.ndarray],
+                          noise_audio: np.ndarray) -> Mixture:
     from sonusai.utils import dbfs_to_sample
 
+    target_audio = np.single(sum(target_audios))
+
     if mixture.snr < -96:
         # Special case for zeroing out target data
         mixture.target_snr_gain = 0
@@ -116,8 +116,8 @@ def _update_mixture_gains(mixdb: MixtureDatabase,
         mixture.target_snr_gain = 1
         mixture.noise_snr_gain = 0
     else:
-        target_energy = np.mean(np.square(np.single(augmented_target_audio)))
-        noise_energy = np.mean(np.square(np.single(noise_segment)))
+        target_energy = np.mean(np.square(target_audio))
+        noise_energy = np.mean(np.square(np.single(noise_audio)))
         noise_gain = np.sqrt(target_energy / noise_energy) / 10 ** (mixture.snr / 20)
 
         # Check for noise_gain > 1 to avoid clipping
@@ -127,9 +127,10 @@ def _update_mixture_gains(mixdb: MixtureDatabase,
         else:
             mixture.target_snr_gain = 1
             mixture.noise_snr_gain = noise_gain
+
     # Check for clipping in mixture
-    gain_adjusted_target_audio = np.single(augmented_target_audio) * mixture.target_snr_gain
-    gain_adjusted_noise_audio = np.single(noise_segment) * mixture.noise_snr_gain
+    gain_adjusted_target_audio = target_audio * mixture.target_snr_gain
+    gain_adjusted_noise_audio = np.single(noise_audio) * mixture.noise_snr_gain
     mixture_audio = gain_adjusted_target_audio + gain_adjusted_noise_audio
     if any(abs(mixture_audio) >= 32768):
         # Clipping occurred; lower gains to bring audio within int16 bounds
